summaryrefslogtreecommitdiff
path: root/libs/ardour/audio_region_importer.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2009-10-26 14:38:58 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2009-10-26 14:38:58 +0000
commitfa5aeb7892fb73d45782b42da731bc5a51418e79 (patch)
treef537bf657cf098076511b47e6f2d6d19203696ec /libs/ardour/audio_region_importer.cc
parent5dd8dc0db35bc851bcdcc9ff5212c4344eafb933 (diff)
change the use of "SMPTE" to "Timecode" to reflect the global economy and the end of american dominance on the world audio production stage
git-svn-id: svn://localhost/ardour2/branches/3.0@5924 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/audio_region_importer.cc')
-rw-r--r--libs/ardour/audio_region_importer.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/libs/ardour/audio_region_importer.cc b/libs/ardour/audio_region_importer.cc
index 19653f55c0..c9203435d5 100644
--- a/libs/ardour/audio_region_importer.cc
+++ b/libs/ardour/audio_region_importer.cc
@@ -127,7 +127,7 @@ string
AudioRegionImporter::get_info () const
{
nframes_t length, position;
- SMPTE::Time length_time, position_time;
+ Timecode::Time length_time, position_time;
std::ostringstream oss;
// Get sample positions
@@ -136,15 +136,15 @@ AudioRegionImporter::get_info () const
std::istringstream iss_position(xml_region.property ("position")->value());
iss_position >> position;
- // Convert to smpte
- session.sample_to_smpte(length, length_time, true, false);
- session.sample_to_smpte(position, position_time, true, false);
+ // Convert to timecode
+ session.sample_to_timecode(length, length_time, true, false);
+ session.sample_to_timecode(position, position_time, true, false);
// return info
oss << _("Length: ") <<
- smpte_to_string(length_time) <<
+ timecode_to_string(length_time) <<
_("\nPosition: ") <<
- smpte_to_string(position_time) <<
+ timecode_to_string(position_time) <<
_("\nChannels: ") <<
xml_region.property ("channels")->value();